@@ -306,7 +306,7 @@ SPVM::$class_name - Short Description
 
 =head1 Description
 
-C<SPVM::$class_name> is the C<$class_name> class in L<SPVM> language.
+The C<$class_name> class of L<SPVM> has methods to do someting.
 
 =head1 Usage
 
@@ -356,7 +356,7 @@ sub generate_native_config_file {
   my $native = $self->native;
   my $new_method;
   if ($native eq 'c') {
-    $new_method = 'new_gnu99';
+    $new_method = 'new_c99';
   }
   elsif ($native eq 'c++') {
     $new_method = 'new_cpp';
@@ -804,7 +804,7 @@ sub generate_basic_test_native_config_file {
   my $native = $self->native;
   my $new_method;
   if ($native eq 'c') {
-    $new_method = 'new_gnu99';
+    $new_method = 'new_c99';
   }
   elsif ($native eq 'c++') {
     $new_method = 'new_cpp';
